California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 87 - ALTERNATIVE ENERGY. RESEARCH, PRODUCTION, INCENTIVES. TAX ON CALIFORNIA OIL. INITIATIVE CONSTITUTIONAL AMENDMENT AND STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1282352 | YES ON 87, CALIFORNIANS FOR CLEAN ENERGY, A COALITION OF CONSUMER, PUBLIC HEALTH AND ENVIRONMENTAL ORGANIZATIONS, SCIENTISTS AND BUSINESS LEADERS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1288982 | CITIZENS FOR RESPONSIBLE ELECTIONS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1282414 | CALIFORNIANS AGAINST HIGHER TAXES - NO ON 87, A COALITION OF TAXPAYERS, EDUCATORS, PUBLIC SAFETY OFFICIALS, BUSINESSES, ENERGY PRODUCERS | OPPOSE